==> git-town-15.3.0.tar.gz: git-town-15.3.0/website/src/SUMMARY.md <==
# Summary

- [Introduction](introduction.md)
- [Q & A](questions.md)
- [Install](install.md)
- [Configuration](configuration.md)
- [Integration](integration.md)
- [Commands](all-commands.md)
  - [Basic workflow](basic-commands.md)
    - [hack](commands/hack.md)
    - [sync](commands/sync.md)
    - [switch](commands/switch.md)
    - [propose](commands/propose.md)
  - [Dealing with errors](error-commands.md)
    - [continue](commands/continue.md)
    - [skip](commands/skip.md)
    - [status](commands/status.md)
    - [undo](commands/undo.md)
  - [Stacked changes](stacked-changes.md)
    - [append](commands/append.md)
    - [prepend](commands/prepend.md)
    - [set-parent](commands/set-parent.md)
    - [diff-parent](commands/diff-parent.md)
  - [Branch types](branch-types.md)
    - [contribute](commands/contribute.md)
    - [observe](commands/observe.md)
    - [park](commands/park.md)
  - [Additional commands](additional-commands.md)
    - [compress](commands/compress.md)
    - [kill](commands/kill.md)
    - [rename-branch](commands/rename-branch.md)
    - [repo](commands/repo.md)
    - [ship](commands/ship.md)
  - [Installation commands](installation-commands.md)
    - [completions](commands/completions.md)
    - [version](commands/version.md)
  - [Configuration commands](configuration-commands.md)
    - [config](commands/config.md)
    - [setup](commands/config-setup.md)
    - [offline](commands/offline.md)
- [Preferences](preferences.md)
  - [configuration file](configuration-file.md)
  - [create-prototype-branches](preferences/create-prototype-branches.md)
  - [hosting-platform](preferences/hosting-platform.md)
  - [hosting-origin-hostname](preferences/hosting-origin-hostname.md)
  - [github-token](preferences/github-token.md)
  - [gitlab-token](preferences/gitlab-token.md)
  - [main-branch](preferences/main-branch.md)
  - [offline](preferences/offline.md)
  - [push-hook](preferences/push-hook.md)
  - [push-new-branches](preferences/push-new-branches.md)
  - [parent](preferences/parent.md)
  - [pererennial-branches](preferences/perennial-branches.md)
  - [pererennial-regex](preferences/perennial-regex.md)
  - [ship-delete-tracking-branch](preferences/ship-delete-tracking-branch.md)
  - [sync-feature-strategy](preferences/sync-feature-strategy.md)
  - [sync-perennial-strategy](preferences/sync-perennial-strategy.md)
  - [sync-prototype-strategy](preferences/sync-prototype-strategy.md)
  - [sync-tags](preferences/sync-tags.md)
  - [sync-upstream](preferences/sync-upstream.md)

==> git-town-16.1.0.tar.gz: git-town-16.1.0/website/src/SUMMARY.md <==
# Summary

- [Introduction](introduction.md)
- [Q & A](questions.md)
- [Install](install.md)
- [Configuration](configuration.md)
- [Integration](integration.md)
- [Commands](all-commands.md)
  - [Basic workflow](basic-commands.md)
    - [hack](commands/hack.md)
    - [sync](commands/sync.md)
    - [switch](commands/switch.md)
    - [propose](commands/propose.md)
  - [Dealing with errors](error-commands.md)
    - [continue](commands/continue.md)
    - [skip](commands/skip.md)
    - [status](commands/status.md)
    - [undo](commands/undo.md)
  - [Stacked changes](stacked-changes.md)
    - [append](commands/append.md)
    - [prepend](commands/prepend.md)
    - [set-parent](commands/set-parent.md)
    - [diff-parent](commands/diff-parent.md)
  - [Branch types](branch-types.md)
    - [contribute](commands/contribute.md)
    - [observe](commands/observe.md)
    - [park](commands/park.md)
  - [Additional commands](additional-commands.md)
    - [compress](commands/compress.md)
    - [kill](commands/kill.md)
    - [rename-branch](commands/rename-branch.md)
    - [repo](commands/repo.md)
    - [ship](commands/ship.md)
  - [Installation commands](installation-commands.md)
    - [completions](commands/completions.md)
    - [version](commands/version.md)
  - [Configuration commands](configuration-commands.md)
    - [config](commands/config.md)
    - [setup](commands/config-setup.md)
    - [offline](commands/offline.md)
- [Preferences](preferences.md)
  - [configuration file](configuration-file.md)
  - [contribution-branches](preferences/contribution-branches.md)
  - [create-prototype-branches](preferences/create-prototype-branches.md)
  - [default-branch-type](preferences/default-branch-type.md)
  - [feature-regex](preferences/feature-regex.md)
  - [gitea-token](preferences/gitea-token.md)
  - [github-token](preferences/github-token.md)
  - [gitlab-token](preferences/gitlab-token.md)
  - [hosting-origin-hostname](preferences/hosting-origin-hostname.md)
  - [hosting-platform](preferences/hosting-platform.md)
  - [main-branch](preferences/main-branch.md)
  - [observed-branches](preferences/observed-branches.md)
  - [offline](preferences/offline.md)
  - [parent](preferences/parent.md)
  - [parked-branches](preferences/parked-branches.md)
  - [perennial-branches](preferences/perennial-branches.md)
  - [pererennial-regex](preferences/perennial-regex.md)
  - [prototype-branches](preferences/prototype-branches.md)
  - [push-hook](preferences/push-hook.md)
  - [push-new-branches](preferences/push-new-branches.md)
  - [ship-delete-tracking-branch](preferences/ship-delete-tracking-branch.md)
  - [ship-strategy](preferences/ship-strategy.md)
  - [sync-feature-strategy](preferences/sync-feature-strategy.md)
  - [sync-perennial-strategy](preferences/sync-perennial-strategy.md)
  - [sync-prototype-strategy](preferences/sync-prototype-strategy.md)
  - [sync-tags](preferences/sync-tags.md)
  - [sync-upstream](preferences/sync-upstream.md)
